scanners

package
v0.0.0-...-bfb27c9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2023 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Overview

Package scanners implements an EBNF scanner returning a slice of tokens.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Scan

func Scan(input []byte) []*tokens.Token

Scan returns a slice containing all the tokens in the input. It always adds an end of input token to that slice.

Types

This section is empty.

Jump to